@@ -7,9 +7,8 @@ import (
 	"errors"
 	"log"
 	"os"
+	"os/exec"
 	"time"
-
-	exec "golang.org/x/sys/execabs"
 )
 
 // StartEc2EndpointProxyServerProcess starts a `aws-vault proxy` process
