@@ -3,7 +3,6 @@ package vault_test
 import (
 	"bytes"
 	"fmt"
-	"io/ioutil"
 	"os"
 	"reflect"
 	"testing"
@@ -55,16 +54,15 @@ s3=
 var defaultsOnlyConfigWithHeader = []byte(`[default]
 region=us-west-2
 output=json
-
 `)
 
 func newConfigFile(t *testing.T, b []byte) string {
 	t.Helper()
-	f, err := ioutil.TempFile("", "aws-config")
+	f, err := os.CreateTemp("", "aws-config")
 	if err != nil {
 		t.Fatal(err)
 	}
-	if err := ioutil.WriteFile(f.Name(), b, 0600); err != nil {
+	if err := os.WriteFile(f.Name(), b, 0600); err != nil {
 		t.Fatal(err)
 	}
 	return f.Name()
@@ -224,10 +222,10 @@ func TestAddProfileToExistingNestedConfig(t *testing.T) {
 	}
 
 	expected := append(nestedConfig, []byte(
-		"\n[profile llamas]\nmfa_serial=testserial\nregion=us-east-1\n\n",
+		"\n[profile llamas]\nmfa_serial=testserial\nregion=us-east-1\n",
 	)...)
 
-	b, _ := ioutil.ReadFile(f)
+	b, _ := os.ReadFile(f)
 
 	if !bytes.Equal(expected, b) {
 		t.Fatalf("Expected:\n%q\nGot:\n%q", expected, b)
@@ -277,7 +275,7 @@ func TestIniWithHeaderSavesWithHeader(t *testing.T) {
 
 	expected := defaultsOnlyConfigWithHeader
 
-	b, _ := ioutil.ReadFile(f)
+	b, _ := os.ReadFile(f)
 
 	if !bytes.Equal(expected, b) {
 		t.Fatalf("Expected:\n%q\nGot:\n%q", expected, b)
